( cd opt/kde/share/doc/HTML/en/kmplayer ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmplayer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/et/et ; rm -rf common )
( cd opt/kde/share/doc/HTML/et/et ; ln -sf /opt/kde/share/doc/HTML/et/common common )
( cd opt/kde/share/doc/HTML/it/it ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/it ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/sv/sv ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/sv ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
