<!DOCTYPE kpartgui>
<kpartgui name="kmplayer" version="11">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="new_window"/>
    <Action name="open"/>
  </Menu>
  <Menu name="view"><text>&amp;View</text>
    <Action name="fullscreen"/>
    <Menu name="zoom"><text>&amp;Zoom</text>
      <Action name="view_zoom_50"/>
      <Action name="view_zoom_100"/>
      <Action name="view_zoom_150"/>
    </Menu>
    <Action name="view_keep_ratio"/>
    <Separator />
    <Action name="view_show_console"/>
    <Separator />
    <Action name="play"/>
    <Action name="pause"/>
    <Action name="stop"/>
    <Separator />
    <Action name="view_arts_control"/>
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="configure"/>
  </Menu>
</MenuBar>
<ActionProperties>
  <Action name="new_window" icon="window_new"/>
  <Action name="play" icon="player_play"/>
  <Action name="pause" icon="player_pause"/>
  <Action name="stop" icon="player_stop"/>
  <Action shortcut="F" name="fullscreen" />
  <Action shortcut="R" name="play" />
  <Action shortcut="P" name="pause" />
  <Action shortcut="S" name="stop" />
  <Action shortcut="C" name="view_arts_control" />
</ActionProperties>
<Toolbar name="mainToolBar"><text></text>
  <Action name="new_window"/>
  <Action name="open"/>
  <Action name="play"/>
  <Action name="pause"/>
  <Action name="stop"/>
  <Separator/>
  <Action name="configure"/>
</Toolbar>
</kpartgui>
